@@ -7,10 +7,8 @@
 #include <stdio.h>
 #include "grib2_int.h"
 
-#define G2C_ERROR 2
-
-#define GRIB2_FILE "gdaswave.t00z.wcoast.0p16.f000.grib2"
-#define GRIB2_INDEX_FILE "gdaswave.t00z.wcoast.0p16.f000.grib2.idx"
+#define GRIB2_FILE "data/gdaswave.t00z.wcoast.0p16.f000.grib2"
+#define GRIB2_INDEX_FILE "data/gdaswave.t00z.wcoast.0p16.f000.grib2.idx"
 
 int
 main()
@@ -45,7 +43,7 @@ main()
         if (!(f = fopen(GRIB2_INDEX_FILE, "r")))
             return G2C_ERROR;
 
-        /* Run seekgb() on data file. */
+        /* Run seekgb() on non-data file. */
         seekgb(f, 0, 16, &lskip, &lgrib);
 
         /* Check results. */
